/*
 Silicom SPE net_device driver for Linux.
 Written by Igor Royzis (c) 1998
 Created: December 9, 1998
*/
#ifndef __silspe
#define __silspe

#define MIN_PACKET              14          // Min ethernet packet
#define MAX_PACKET              1514        // Max ethernet packet
#define HEADER_LENGTH           8           // Buffer header length

#define TRANSMIT_BUFFER_START   0
#define TRANSMIT_FRAME_LENGTH   (MAX_PACKET + 8)  // frame + hardware header
#define TRANSMIT_BUFFER_SIZE    0x2000            // 8K for transmit buffer

//************************************************************************
//    Bank 0 Status Register Bit Definitions
//************************************************************************

#define DB0IntAllInts 0x0f

//************************************************************************
//    Bank 0 Mask Register Bit Definitions
//************************************************************************
#define DB0UnMaskInt 0x00
#define DB032IO 0x10
#define DB0CAR 0x20                   //  Set for Current Address Select.

// Bank 0 ID register definitions
#define IdRegMask  0x2c               // Signature mask
#define IdRegSign  0x24               // Signature


//************************************************************************
//        Bank 1 Control Register Bit Definitions
//************************************************************************
#define B11_BusWidth 0x02             //  host bus width
#define B11_AsicMode 0x20             //  set asic mode
#define B11_EarlyTimingEnable 0x40    //  enable early timing
#define B11_TurnOnInterrupts 0x80     //  enables int req lines

//************************************************************************
//        Bank 1 Alt Ready Test Register Bit Definitions
//************************************************************************
#define B11_PassFail 0x01             //  test result
#define B11_TestEnable 0x02           //  test enable

//************************************************************************
//        Bank 2 Control Register Bit Definitions
//************************************************************************
#define B21_XUR_ENABLE 0x01           //  XUR enable for early sends
#define B21_BusType 0x10              //  pcmcia/isa interface indicator
#define B21_TxChainIntMode 0x20       //  tx chanining interrupt mode
#define B21_TxChainErrStop 0x40       //  stop on error
#define B21_IgnoreBadFrames 0x80      //  reject rec'd frames with errors

//************************************************************************
//        Bank 2 Tx/Rx Control Register Bit Definitions
//************************************************************************
#define B22_Promiscuous 0x01          //  rx - enable promiscuous mode
#define B22_BdcstDisable 0x02         //  rx - disable bdcst
#define B22_CRCinMemory 0x04          //  rx - CRC with frame
#define B22_Multicast 0x08            //  rx - enable multicast
#define B22_NoSrcAddrIns 0x10         //  tx - disable src addr insert
#define B22_MultiIA 0x20              //  rx - enable multiple IAs
#define B22_LoopbackMode 0x0c0        //  set loopback mode

//************************************************************************
//        Bank 2 Configuration Register Bit Definitions
//************************************************************************
#define B23_LinkIntegrety 0x01        //  disable link integrity
#define B23_PolarityCorr 0x02         //  enable polarity correction function
#define B23_NetType 0x04              //  type of analog board connected
#define B23_JabDisable 0x08           //  disables jabber protect function
#define B23_AutoPort 0x10             //  disables auto port ( TPE/AUI ) detection
#define B23_NetSelect 0x20            //  select TPE/AUI or BNC/AUI analog board
#define B23_TestBits 0x0c0            //  testability bits

//************************************************************************
//    Transmit Result Bit Definitions
//************************************************************************
#define TXS_Collision 0x8000          //  collision(s) detected during transmit
#define TXS_Unused4000 0x4000         //  unused
#define TXS_TransmitOK 0x2000         //  transmit completed ok
#define TXS_Unused1000 0x1000         //  unused
#define TXS_LateCollision 0x0800      //  late collision
#define TXS_LostCRS 0x0400            //  lost the CRS signal
#define TXS_Unused0200 0x0200         //  unused
#define TXS_Underrun 0x0100           //  DMA underrun
#define TXS_Defered 0x0080            //  transmit deferred
#define TXS_HeartBeat 0x0040          //  SQE test passed
#define TXS_MaxCollisions 0x0020      //  transmit failed due to too many collisions
#define TXS_Unused0010 0x0010         //  unused
#define TXS_Collisions 0x000f         //  collision count mask

#define TXS_TransmitFail (TXS_LateCollision+TXS_LostCRS+TXS_Underrun+TXS_MaxCollisions)

//************************************************************************
//    Receive Result Bit Definitions
//************************************************************************

#define RXS_TypeField 0x8000          //  frame had type field
#define RXS_0mask 0x4200              //  fixed 0s
#define RXS_ReceiveOK 0x2000          //  receive completed ok
#define RXS_LengthError 0x1000        //  receive length error
#define RXS_CRC 0x0800                //  crc error
#define RXS_Alignment 0x0400          //  alignment error
#define RXS_Overrun 0x0100            //  DMA overrun error
#define RXS_Short 0x0080              //  short frame error
#define RXS_1mask 0x0010              //  fixed 1s
#define RXS_IAmatch 0x0002            //  IA in frame matched local IA
#define RXS_Collision 0x0001          //  receive collision error
#define RXS1_RxOK 0x20                //  Recieve Ok.

//
// SPE595 Commands
#define CSWP0 0x00                    //  switch to port 0 no-op
#define CSWP1 0x40                    //  switch to port 1 no-op
#define CSWP2 0x80                    //  switch to port 2 no-op
#define CSWP3 0x0C0                   //  switch to port 3 no-op

#define CMConfig 0x02                 //  Undocumented 593 Configure command.
#define CMCSET 0x03                   //  multicast setup
#define CTx 0x04                      //  start transmit
#define CTDR 0x05                     //  time domain reflectometer
#define CDUMP 0x06                    //  dump registers
#define CDIAG 0x07                    //  start diagnostic
#define CTxNoCRC 0x14                 //  transmit with no CRC
#define CABORT 0x0D                   //  abort current command
#define CRSTx 0x1C                    //  resume transmit
#define CCTx 0x15                     //  continuous transmit (TBD)
#define CPWRD 0x18                    //  power down (TBD)
#define CSETS 0x16                    //  set test mode (high impedence)
#define CRETS 0x17                    //  reset test mode (normal)
#define CRST 0x0E                     //  reset chip
#define CSELR 0x1E                    //  selective reset

#define CRxENB 0x08                   //  receive enable
#define CRx 0x08                      //  receive complete event
#define CRxDISB 0x0A                  //  receive disable
#define CSTPRx 0x0B                   //  stop receive

//
// DB0InterruptStatus bit definitions
#define DB0IntRxStp 0x01              //  receive stop reg hit interrupt
#define DB0IntRx 0x02                 //  receive interrupt
#define DB0IntTx 0x04                 //  transmit interrupt
#define DB0IntExec 0x08               //  execution event interrupt
#define DB0IntExState 0x30            //  execution states
#define DB0IntRxState 0x0C0           //  receive states


//
// DB0Mask bit masks
#define DB0MaskStp 0x01               //  receive stop interrupts
#define DB0MaskRx 0x02                //  receive interrupts
#define DB0MaskTx 0x04                //  transmit interrupts
#define DB0MaskExec 0x08              //  execution interrupts
#define DB0MaskBase 0x20              //  read BAR or CAR

#define DB0MaskInt   (DB0MaskTx | DB0MaskRx | DB0MaskStp | DB0MaskExec)
#define DBOUnMaskInt (~DB0MaskInt)     // unmask all interrupts

#define CAR_Bit 0x20                  //  Set for Current Address Select.
#define BAR_Bit (~CAR_Bit)             // Set for Base Address Select.

//
// SPE595 Receiver Buffer Event Field Flags
#define RxDone 0x08                   //  receive complete

//
// SPE595 Transmit block command field flags
#define TxDone 0x80                   //  transmit done
#define TxChainBit 0x8000             //  Transmit Chain bit in Byte Count field

//
// SPE595 Receive Buffer Status Field Flags
#define DRS0Collision 0x01            //  collision error
#define DRS0MatchIA 0x02              //  IA matched flag
#define DRS0Short 0x80                //  short frame error

#define DRS1Overrun 0x01              //  overrun error
#define DRS1Alignment 0x04            //  alignment error
#define DRS1Crc 0x08                  //  CRC error
#define DRS1Length 0x10               //  length error
#define DRS1RxOK 0x20                 //  receive frame is OK
#define DRS1Type 0x80                 //  type error

//
// SPE595 Transmit Buffer Status Field Flags
#define DTS0NumCollisions 0x0f        //  number of collisions the frame experienced
#define DTS0MaxCollisions 0x20        //  max collisions occurred
#define DTS0HeartBeat 0x40            //  coll detect test passed after last Tx
#define DTS0TxDeferred 0x80           //  Tx deferred due to link activity

#define DTS1Underrun 0x01             //  underrun error
#define DTS1LostCrs 0x04              //  lost carrier sense
#define DTS1LateCol 0x08              //  late collision detected
#define DTS1TxOK 0x20                 //  transmission was OK
#define DTS1Collision 0x80            //  last Tx experienced collision

#define DTS0Fatal    DTS0MaxCollisions // low byte fatal errors
#define DTS1Fatal    (DTS1Underrun+DTS1LostCrs+DTS1LateCol)


/*-----------------------------------------------------------------------------
 595 bank port structures
*-----------------------------------------------------------------------------*/

// Bank 0
#define BCommand      0     //command register
#define B0IntStatus   1     //interrupt/status register
#define B0Identity    2     //ID register
#define B0Mask        3     //control bit mask
#define B0RxAddr      4     //receive CAR/BAR address low byte
#define B0RxAddr2     5     //receive CAR/BAR address high byte
#define B0RxStop      6     //receive stop address low byte
#define B0RxStop2     7     //receive stop address high byte
#define B0Res1        8     //reserved
#define B0Res2        9     //reserved
#define B0TxAddr      10    //transmit CAR/BAR address low byte
#define B0TxAddr2     11    //transmit CAR/BAR address high byte
#define B0HostAddr    12    //host address low byte
#define B0HostAddr2   13    //host address high byte
#define B0MemPort     14    //local memory I/O port low byte
#define B0MemPort2    15    //local memory I/O port high byte

// Bank 1
#define B1Command     0     //command register
#define B1Control     1     //host bus width, tri-state INT line
#define B1IntSel      2     //interrupt selecet, EEPROM decode window
#define B1IOMap       3     //I/O mapping window
#define B1Res1        4     //reserved
#define B1Res2        5     //reserved
#define B1Res3        6     //reserved
#define B1Res4        7     //reserved
#define B1RxLowLim    8     //receive buffer lower limit
#define B1RxUpLim     9     //receive buffer upper limit
#define B1TxLowLim   10     //transmit buffer lower limit
#define B1TxUpLim    11     //transmit buffer upper limit
#define B1Flash      12     //flash page select, flash write enable
#define B1AltRdy     13     //alt rdy, smout enable
#define B1Res5       14     //reserved
#define B1Res6       15     //reserved

// Bank 2
#define B2Command     0     //command register
#define B2Control1    1     //Tx chain, pcmcia or isa
#define B2Control2    2     //broadcast, multicast, promiscuous, etc.
#define B2Config      3     //link integ, polarity, TPE, etc
#define B2IAddress0   4     //Individual Address byte 0
#define B2IAddress1   5     //IA byte 1
#define B2IAddress2   6     //IA byte 2
#define B2IAddress3   7     //IA byte 3
#define B2IAddress4   8     //IA byte 4
#define B2IAddress5   9     //IA byte 5
#define B2EEPROM      10    //EEPROM access port
#define B2NoResource  11    //no resources count
#define B2IAddProm    12    //IA PROM port
#define B2Res1        13    //reserved
#define B2Res2        14    //reserved
#define B2Res3        15    //reserved

// Bank 3
#define B3Command     0     //command register
#define B3Res1        1     //reserved
#define B3RxTemp      2     //receive temp register low
#define B3RxTemp2     3     //receive temp register high
#define B3RxByteC     4     //receive byte count low
#define B3RxByteC2    5     //receive byte count high
#define B3TxTemp      6     //transmit temp register low
#define B3TxTemp2     7     //transmit temp register high
#define B3TxByteC     8     //transmit byte count low
#define B3TxByteC2    9     //transmit byte count high
#define B3Res2       10     //reserved
#define B3Res3       11     //reserved
#define B3Res4       12     //reserved
#define B3Res5       13     //reserved
#define B3Res6       14     //reserved
#define B3Res7       15     //reserved


// 593 configuration table
#define C593TableLength 10  // Configuration parameters table length
#define C593ModeIndex    6  // Word offset of Promiscuous mode on/off
#define C593_EnablePromisc 0x0100 // Mask to enable promiscuous mode


// Prototypes used by a PCMCIA network client
int  spe_open(struct net_device *dev);
int  spe_start_xmit(struct sk_buff *skb, struct net_device *dev);
void spe_interrupt(int irq, void *dev_id, struct pt_regs *regs);
int  spe_close(struct net_device *dev);
struct net_device_stats *spe_get_stats(struct net_device *dev);
void set_multicast_list(struct net_device *dev);
int  spe_reset(struct net_device *dev);

//
int  spe_drvinit(struct net_device *dev);

#endif
/* EOF */
